@@ -1,3 +1,5 @@
+from typing import List
+
 from codenames.game import Guess, Hint
 from pydantic import BaseModel
 
@@ -5,7 +7,7 @@ from . import ModelIdentifier, Solver
 
 
 class BaseResponse(BaseModel):
-    status_code: int = 200
+    pass
 
 
 class LoadModelsResponse(BaseResponse):
@@ -23,3 +25,16 @@ class GenerateGuessResponse(BaseResponse):
     suggested_guess: Guess
     used_solver: Solver
     used_model_identifier: ModelIdentifier
+
+
+class StemResponse(BaseResponse):
+    root: str
+
+
+class Similarity(BaseModel):
+    word: str
+    similarity: float
+
+
+class MostSimilarResponse(BaseResponse):
+    most_similar: List[Similarity]
